Exception: PlanMyStuff::AuthorizationError

Inherits:
Error
  • Object
show all
Defined in:
lib/plan_my_stuff/errors.rb

Overview

Raised when a caller is not authorized to perform an action (e.g. a non-support user attempts to manage approvers on an issue).